Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'org.eclipse.osbp.xtext.datainterchange/emf-gen/org/eclipse/osbp/xtext/datainterchange/DataInterchangeJoin.java')
-rw-r--r--org.eclipse.osbp.xtext.datainterchange/emf-gen/org/eclipse/osbp/xtext/datainterchange/DataInterchangeJoin.java24
1 files changed, 12 insertions, 12 deletions
diff --git a/org.eclipse.osbp.xtext.datainterchange/emf-gen/org/eclipse/osbp/xtext/datainterchange/DataInterchangeJoin.java b/org.eclipse.osbp.xtext.datainterchange/emf-gen/org/eclipse/osbp/xtext/datainterchange/DataInterchangeJoin.java
index 0087f28..5fa001f 100644
--- a/org.eclipse.osbp.xtext.datainterchange/emf-gen/org/eclipse/osbp/xtext/datainterchange/DataInterchangeJoin.java
+++ b/org.eclipse.osbp.xtext.datainterchange/emf-gen/org/eclipse/osbp/xtext/datainterchange/DataInterchangeJoin.java
@@ -15,7 +15,7 @@
*/
package org.eclipse.osbp.xtext.datainterchange;
-import org.eclipse.osbp.dsl.semantic.entity.LEntity;
+import org.eclipse.osbp.dsl.semantic.entity.LEntityReference;
/**
* <!-- begin-user-doc -->
@@ -27,7 +27,7 @@ import org.eclipse.osbp.dsl.semantic.entity.LEntity;
* </p>
* <ul>
* <li>{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getBeanAttr1 <em>Bean Attr1</em>}</li>
- * <li>{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getJoinEntity <em>Join Entity</em>}</li>
+ * <li>{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getJoinRef <em>Join Ref</em>}</li>
* <li>{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getBeanAttr2 <em>Bean Attr2</em>}</li>
* </ul>
*
@@ -63,30 +63,30 @@ public interface DataInterchangeJoin extends DataInterchangeLazyResolver {
void setBeanAttr1(DataInterchangeJoinAttr value);
/**
* Returns the value of the '<em><b>Join Entity</b></em>' reference.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Join Entity</em>' reference isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Join Entity</em>' reference.
* @see #setJoinEntity(LEntity)
* @see org.eclipse.osbp.xtext.datainterchange.DataDSLPackage#getDataInterchangeJoin_JoinEntity()
* @model
* @generated
*/
- LEntity getJoinEntity();
+ LEntityReference getJoinRef();
/**
* Sets the value of the '{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getJoinEntity <em>Join Entity</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Join Entity</em>' reference.
* @see #getJoinEntity()
* @generated
*/
- void setJoinEntity(LEntity value);
+ void setJoinRef(LEntityReference value);
/**
* Returns the value of the '<em><b>Bean Attr2</b></em>' containment reference.
@@ -63,30 +63,30 @@ public interface DataInterchangeJoin extends DataInterchangeLazyResolver {
void setBeanAttr1(DataInterchangeJoinAttr value);
/**
- * Returns the value of the '<em><b>Join Entity</b></em>' reference.
+ * Returns the value of the '<em><b>Join Ref</b></em>' reference.
* <!-- begin-user-doc -->
* <p>
@@ -63,30 +63,30 @@ public interface DataInterchangeJoin extends DataInterchangeLazyResolver {
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Join Entity</em>' reference isn't clear,
+ * If the meaning of the '<em>Join Ref</em>' reference isn't clear,
* there really should be more of a description here...
* </p>
@@ -63,30 +63,30 @@ public interface DataInterchangeJoin extends DataInterchangeLazyResolver {
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Join Entity</em>' reference.
- * @see #setJoinEntity(LEntity)
- * @see org.eclipse.osbp.xtext.datainterchange.DataDSLPackage#getDataInterchangeJoin_JoinEntity()
+ * @return the value of the '<em>Join Ref</em>' reference.
+ * @see #setJoinRef(LEntityReference)
+ * @see org.eclipse.osbp.xtext.datainterchange.DataDSLPackage#getDataInterchangeJoin_JoinRef()
* @model
* @generated
@@ -63,30 +63,30 @@ public interface DataInterchangeJoin extends DataInterchangeLazyResolver {
/**
- * Sets the value of the '{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getJoinEntity <em>Join Entity</em>}' reference.
+ * Sets the value of the '{@link org.eclipse.osbp.xtext.datainterchange.DataInterchangeJoin#getJoinRef <em>Join Ref</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -63,30 +63,30 @@ public interface DataInterchangeJoin extends DataInterchangeLazyResolver {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Join Entity</em>' reference.
- * @see #getJoinEntity()
+ * @param value the new value of the '<em>Join Ref</em>' reference.
+ * @see #getJoinRef()
* @generated
*/

Back to the top